( cd usr/lib ; rm -rf libbfd.so )
( cd usr/lib ; ln -sf libbfd-2.17.50.0.17.20070615.so libbfd.so )
( cd usr/lib ; rm -rf libopcodes.so )
( cd usr/lib ; ln -sf libopcodes-2.17.50.0.17.20070615.so libopcodes.so )
( cd usr/i486-slackware-linux/lib ; rm -rf ldscripts )
( cd usr/i486-slackware-linux/lib ; ln -sf /usr/lib/ldscripts ldscripts )
( cd usr/i486-slackware-linux/bin ; rm -rf as )
( cd usr/i486-slackware-linux/bin ; ln -sf /usr/bin/as as )
( cd usr/i486-slackware-linux/bin ; rm -rf strip )
( cd usr/i486-slackware-linux/bin ; ln -sf /usr/bin/strip strip )
( cd usr/i486-slackware-linux/bin ; rm -rf ar )
( cd usr/i486-slackware-linux/bin ; ln -sf /usr/bin/ar ar )
( cd usr/i486-slackware-linux/bin ; rm -rf ranlib )
( cd usr/i486-slackware-linux/bin ; ln -sf /usr/bin/ranlib ranlib )
( cd usr/i486-slackware-linux/bin ; rm -rf nm )
( cd usr/i486-slackware-linux/bin ; ln -sf /usr/bin/nm nm )
( cd usr/i486-slackware-linux/bin ; rm -rf ld )
( cd usr/i486-slackware-linux/bin ; ln -sf /usr/bin/ld ld )
( cd usr/i486-slackware-linux/bin ; rm -rf objdump )
( cd usr/i486-slackware-linux/bin ; ln -sf /usr/bin/objdump objdump )
( cd usr/i486-slackware-linux/bin ; rm -rf objcopy )
( cd usr/i486-slackware-linux/bin ; ln -sf /usr/bin/objcopy objcopy )
